from distutils.core import setup
setup(
 name = "unpackList",
 version = '1.0.0',
 py_modules = ['unpackList'],
 author = 'Santhosh',
 author_email = 'dummy@zombie.com',
 url = 'http://www.google.com',
 description = "This unpacks the list passed to it",
)
